'use strict';
angular.module('portFolio', []);

angular.module('portFolio')
.service("portfolioRepository", ['$http', function ($http) {
    this.createItem = function (data) {
        var req = {
            method: 'PUT',
            url: '/portfolioapp/' + data._id,
            data: data,
        };
        return $http(req);
    }

    this.getAllItems = function () {
        var req = {
            method: 'GET',
            url: '/portfolioapp/_design/app/_view/show_all'
        };
        return $http(req);
    }

    this.deleteItem = function (data) {
        var req = {
            method: 'DELETE',
            url: '/portfolioapp/' + data._id + '?rev=' + data._rev
        };
        return $http(req);
    }
}]);

angular.module('portFolio')
  .controller('portfolioController', ["portfolioRepository","$filter", function (portfolioRepository,$filter) {
      var ctr = this;
      this.serverError = "";

      function refreshData() {
          portfolioRepository.getAllItems().success(function (d) {
              ctr.portfolioItems = d.rows.map(function (o) { return o.value; })
          });
          ctr.currentItem = {};
      }

      refreshData();

      this.saveItem = function () {
          if (!this.currentItem.stockName) return;

          if (!this.currentItem._id) {
              this.currentItem._id = "client1" + ((new Date()).getTime()).toString();
              portfolioRepository.createItem(this.currentItem)
                  .success(function () { refreshData(); })
                    .error(function () { ctr.serverError = "Unable to save." });
              this.currentItem = {};
          }
          else {
              portfolioRepository.createItem(this.currentItem)
                  .success(function () { refreshData(); })
                    .error(function () { ctr.serverError = "Unable to save." });
          }
      }

      this.deleteItem = function (index) {
          portfolioRepository.deleteItem(this.portfolioItems[index])
                  .success(function () { refreshData(); })
                    .error(function () { ctr.serverError = "Unable to delete." });
      }

      this.createNew = function () {
          this.currentItem = {};
      }

      this.setSelectedItem = function (i) {        
          this.currentItem = angular.copy(this.portfolioItems[i]);
          this.currentItem.date = $filter('date')(this.currentItem.date,"yyyy-MM-dd");
      }
  }]);